@@ -10,7 +10,7 @@ use File::Spec;
 use IPC::Open3;
 use Symbol 'gensym';
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 our @EXPORT = qw(
     pod_file_spelling_ok
@@ -20,12 +20,14 @@ our @EXPORT = qw(
     all_pod_files
     set_pod_file_filter
     has_working_spellchecker
+    set_pod_parser
 );
 
 my $TEST = Test::Builder->new;
 
 my $SPELLCHECKER;
 my $FILE_FILTER = sub { 1 };
+my $POD_PARSER  = Pod::Spell->new;
 
 sub spellchecker_candidates {
     # if they've specified a spellchecker, use only that one
@@ -112,8 +114,7 @@ sub invalid_words_in {
     open my $handle, '>', \$document;
 
     # save digested POD to the string $document
-    my $checker = Pod::Spell->new;
-    $checker->parse_from_file($file, $handle);
+    $POD_PARSER->parse_from_file($file, $handle);
 
     my @words = _get_spellcheck_results($document);
 
@@ -238,6 +239,10 @@ sub set_pod_file_filter {
     $FILE_FILTER = shift;
 }
 
+sub set_pod_parser {
+    $POD_PARSER = shift;
+}
+
 1;
 
 __END__
@@ -395,6 +400,13 @@ L</all_pod_files_spelling_ok>).
         return 1;
     });
 
+=head2 set_pod_parser($object)
+
+By default L<Pod::Spell> is used to generate text suitable for spellchecking
+from the input POD.  If you want to use a different parser, perhaps a
+customized subclass of L<Pod::Spell>, call C<set_pod_parser> with an object
+that is-a L<Pod::Parser>.
+
 =head1 SEE ALSO
 
 L<Pod::Spell>
@@ -407,7 +419,7 @@ Heavily based on L<Test::Pod> by Andy Lester and brian d foy.
 
 =head1 MAINTAINER
 
-Shawn M Moore C<< <sartak@bestpractical.com> >>
+Shawn M Moore C<< <code@sartak.org> >>
 
 =head1 COPYRIGHT
 
